@@ -12,6 +12,8 @@ Components.utils.import("resource://gre/modules/Services.jsm");
 
 XPCOMUtils.defineLazyModuleGetter(this, "Deprecated",
                                   "resource://gre/modules/Deprecated.jsm");
+XPCOMUtils.defineLazyModuleGetter(this, "AppConstants",
+                                  "resource://gre/modules/AppConstants.jsm");
 
 const DB_VERSION = 4;
 const DAY_IN_MS  = 86400000; // 1 day in milliseconds
@@ -349,7 +351,26 @@ FormHistory.prototype = {
     },
 
     moveToDeletedTable : function moveToDeletedTable(values, params) {
-//@line 372 "/build/bluegriffon/src/mozilla-central-fec90cbfbaad/toolkit/components/satchel/nsFormHistory.js"
+        if (AppConstants.platform == "android") {
+            this.log("Moving entries to deleted table.");
+
+            let stmt;
+
+            try {
+                // Move the entries to the deleted items table.
+                let query = "INSERT INTO moz_deleted_formhistory (guid, timeDeleted) ";
+                if (values) query += values;
+                stmt = this.dbCreateStatement(query, params);
+                stmt.execute();
+            } catch (e) {
+                this.log("Moving deleted entries failed: " + e);
+                throw e;
+            } finally {
+                if (stmt) {
+                    stmt.reset();
+                }
+            }
+        }
     },
 
     get dbConnection() {
@@ -605,7 +626,7 @@ FormHistory.prototype = {
     },
 
     dbCreateTable: function(name, table) {
-        let tSQL = [[col, table[col]].join(" ") for (col in table)].join(", ");
+        let tSQL = Object.keys(table).map(col => [col, table[col]].join(" ")).join(", ");
         this.log("Creating table " + name + " with " + tSQL);
         this.dbConnection.createTable(name, tSQL);
     },
@@ -747,7 +768,7 @@ FormHistory.prototype = {
 
         // Generate a GUID for each login and update the DB.
         query = "UPDATE moz_formhistory SET guid = :guid WHERE id = :id";
-        for each (let id in ids) {
+        for (let id of ids) {
             let params = {
                 id   : id,
                 guid : this.generateGUID()
@@ -783,7 +804,7 @@ FormHistory.prototype = {
         for (let name in this.dbSchema.tables) {
             let table = this.dbSchema.tables[name];
             let query = "SELECT " +
-                        [col for (col in table)].join(", ") +
+                        Object.keys(table).join(", ") +
                         " FROM " + name;
             try {
                 let stmt = this.dbConnection.createStatement(query);
@@ -825,7 +846,8 @@ FormHistory.prototype = {
       *                    closed.
      */
     _dbClose : function FH__dbClose(aBlocking) {
-        for each (let stmt in this.dbStmts) {
+        for (let query in this.dbStmts) {
+            let stmt = this.dbStmts[query];
             stmt.finalize();
         }
         this.dbStmts = {};
@@ -869,5 +891,5 @@ FormHistory.prototype = {
     }
 };
 
-let component = [FormHistory];
+var component = [FormHistory];
 this.NSGetFactory = XPCOMUtils.generateNSGetFactory(component);
